%define libname         ocaml-mascot-lib

Name:           mascot
Version:        1.0
Release:        %mkrel 11
Summary:        Style-checker for OCaml sources
License:        GPL v3
Group:          Development/OCaml
URL:            http://mascot.x9c.fr/
Source0:        http://download.ocamlcore.org/mascot/%{version}/sources/mascot-%{version}.tar.gz
Source1:        mascot-man-page-%{version}.1
Source2:        example.conf
Patch0:         mascot-1.0.fix-build-doc.patch
Patch1:         mascot-1.0-mageia-fix-ocaml-4.02-build.patch
Patch2:         mascot-1.0.fix-build.patch
BuildRequires:  ocaml-findlib
BuildRequires:  ocaml-compiler-libs
BuildRequires:  ocaml-camlp4-devel
Requires:       ocaml-camlp4

%description
Mascot is a style-checker for OCaml sources. It provides checks in various
categories: code, documentation, interface, metrics, and typography. The
goal of the tool is to allow a (team of) developer(s) to enforce style
properties over a source codebase for greater coherency and style
uniformity. The tool is highly customizable, allowing one to choose the
checks to perform, as well as exceptions to those checks in given files.
Moreover, a plugin system allows the developer to add its own checks, and
output modes.

Bundled output modes range from bare text to CheckStyle- and
JDepend-compatible XML file in order to allow integration with Jenkins.


%package -n     %{libname}
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}
Requires:       ocaml-compiler
Requires:       ocaml-camlp4-devel
Requires:       ocaml-compiler-libs

%description -n %{libname}
This package contains libraries and signature files for developing
applications with %{name}.

%package -n     %{libname}-devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{libname} = %{version}-%{release}

%description -n %{libname}-devel
This package contains native libraries files for developing
applications with %{name}.

%prep
%setup -q -n mascot-%{version}
%autopatch -p1

%build
sh configure
make all
make doc
mv doc manual

# Fix META file
sed -i 's/mascot/mascotLibrary/g' META

%check
make tests

%install
export DESTDIR=%{buildroot}
export OCAMLFIND_DESTDIR=%{buildroot}/%{_libdir}/ocaml
mkdir -p $OCAMLFIND_DESTDIR/mascot
make install PATH_OCAMLFIND="/usr/bin/ocamlfind"

# make an easier command line invocation
install -d -m 755 %{buildroot}/%{_bindir}
pushd %{buildroot}%{_bindir}/
ln -s \
  %{_libdir}/ocaml/mascot/mascot.native \
  mascot
popd

mkdir -p %{buildroot}%{_mandir}/man1
cp %{SOURCE1} %{buildroot}%{_mandir}/man1/mascot.1
cp %{SOURCE2} .

%files
%doc README COPYING CHANGES FEATURES VERSION
%doc manual/
%doc example.conf
%dir %{_libdir}/ocaml/mascot
%{_libdir}/ocaml/mascot/mascot.byte
%{_libdir}/ocaml/mascot/mascot.native
%{_bindir}/mascot
%{_mandir}/man1/mascot.1*

%files -n %{libname}
%doc tests/
%doc ocamldoc/
%{_libdir}/ocaml/mascot/META
%{_libdir}/ocaml/mascot/*.cmi
%{_libdir}/ocaml/mascot/*.cmo

%files -n %{libname}-devel
%{_libdir}/ocaml/mascot/*.cmx
%{_libdir}/ocaml/mascot/*.o


%changelog
* Sun Sep 25 2016 pterjan <pterjan> 1.0-11.mga6
+ Revision: 1056217
- Rebuild for fix in ocaml

* Sat Feb 27 2016 pterjan <pterjan> 1.0-10.mga6
+ Revision: 979935
- Finish patching for new ocaml
- Start fixing build

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild
    - Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 1.0-8.mga5
+ Revision: 749305
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 1.0-7.mga5
+ Revision: 725119
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 1.0-6.mga5
+ Revision: 682171
- Mageia 5 Mass Rebuild

* Wed Jan 01 2014 malo <malo> 1.0-5.mga4
+ Revision: 563723
- add patch to fix build with newer ocaml

  + umeabot <umeabot>
    - Mageia 4 Mass Rebuild

* Thu Jul 25 2013 malo <malo> 1.0-4.mga4
+ Revision: 457978
- add missing requires

* Tue Feb 05 2013 malo <malo> 1.0-3.mga3
+ Revision: 394690
- cut description a bit
- fix META file

* Sat Jan 12 2013 umeabot <umeabot> 1.0-2.mga3
+ Revision: 359417
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 01 2012 blue_prawn <blue_prawn> 1.0-1.mga3
+ Revision: 301612
- build requires ocaml-compiler-libs
- reset mkrel for version 1.0
- updated to version 1.0, and added a patch to fix building the docs
- updated to version 1.0, and added a patch to fix building the docs
- updated to version 1.0, and added a patch to fix building the docs
- updated to version 1.0, and added a patch to fix building the docs
- updated to version 1.0, and added a patch to fix building the docs
- updated to version 1.0, and added a patch to fix building the docs
- rebuild for ocaml-4.00.0
- rebuild for ocaml-4.00.0

* Sat Sep 29 2012 blue_prawn <blue_prawn> 1.0beta-4.mga3
+ Revision: 300592
- new rpm group for ocaml
- removed trailing white space in arg in the man page

* Fri Aug 31 2012 blue_prawn <blue_prawn> 1.0beta-3.mga3
+ Revision: 285927
- made a basic man page from the --help message and the description on the index of the home-page
- also provide the example configuration file that is provided on the website on the example page, that is not included in the manual

* Thu Aug 30 2012 blue_prawn <blue_prawn> 1.0beta-2.mga3
+ Revision: 285905
- fixed a typo
- build requires camlp4
- imported package mascot

